# Adapters API

This page documents the built-in adapters provided by pydapter.

## CSV Adapter

::: pydapter.adapters.csv_ options: show_root_heading: true show_source: true

## JSON Adapter

::: pydapter.adapters.json_ options: show_root_heading: true show_source: true

## TOML Adapter

::: pydapter.adapters.toml_ options: show_root_heading: true show_source: true
